import os
import platform

# Environment variables that can be used to configure
# what is tested.

# Whether or not to pause the CI. Useful when needing to use
# a static MAAS instance.
PAUSE_CI = bool(os.environ.get('PAUSE_CI', False))

# Series to install on deployed nodes.
NODE_SERIES = os.environ.get('NODE_SERIES', 'bionic')

# MAAS user account
ADMIN_USER = "admin"
PASSWORD = "test"

# Whether or not the ARM nodes should be used
# in the test.
DO_NOT_USE_ARM_NODES = bool(
    os.environ.get('DO_NOT_USE_ARM_NODES', True))

USE_ARM_NODES = not DO_NOT_USE_ARM_NODES
USE_PPC_NODES = bool(os.environ.get('USE_PPC_NODES', False))
USE_ARM64_NODES = bool(os.environ.get('USE_ARM64_NODES', False))

CLUSTER_CONTROLLER_IP = '10.245.136.6'

SQUID_DEB_PROXY_URL = 'http://10.55.32.185:8000'
# HTTP proxy used to access the external world.
HTTP_PROXY = "http://162.213.35.104:3128"

# Whether or not set the http proxy. Currently only working on raring
DO_NOT_SET_PROXY = bool("raring" not in platform.linux_distribution())

# Whether or not the cluster controller nodes in different network
# should be used.
USE_CC_NODES = bool(os.environ.get('USE_CC_NODES', False))

MAAS_URL = "http://10.245.136.6:5240/MAAS"
MAIN_ARCHIVE = "http://us.archive.ubuntu.com/ubuntu"
PORTS_ARCHIVE = "http://ports.ubuntu.com/ubuntu-ports"
USER_DATA_URL = "http://10.245.136.6:5240/MAAS/metadata/enlist/latest/user-data"
ENLIST_PRESEED_URL = (
    "http://10.245.136.6:5240/MAAS/metadata/latest/enlist-preseed?op="
    "get_enlist_preseed")

SLAVES = [
    {
        "hostname": "lenovo-RD230-01",
        "mac": "00:25:9C:2F:C7:9E",
        "ip": "10.245.136.5",
    },
    # Jenkins master running on on old jenkins slave.
    # Currently used as the new lander
    {
        "hostname": "lenovo-RD230-01-jenkins-master",
        "mac": "00:e0:81:dd:d1:cf",
        "ip": "10.245.136.2",
    },
    {
        "hostname": "HP-DL360-Gen9",
        "mac": "94:18:82:76:C0:64",
        "ip": "10.245.136.7",
    },
]

# Uses the pre-1.6 API, where a cluster interface had no "name" field.
# MAAS will take the name from the "interface" field, as long as it's
# a unique name within the cluster.  Newer clients would pass a name.
REGION_DHCP_CONFIG = {
    "ip": "10.245.136.6",
    "interface": "eth1",
    "subnet_mask": "255.255.248.0",
    "broadcast_ip": "10.245.143.255",
    "router_ip": "10.245.136.1",
    "management": 2,
    "ip_range_low": "10.245.136.10",
    "ip_range_high": "10.245.136.200",
    # add cidr as it is now default in new networking configs.
    "cidr": "10.245.136.0/21"
}

# Lenovo machines
POWER_USER = "root"
POWER_PASS = "ubuntu"
REGION_CONTROLLER_NODES = {
    # lenovo-RD230-03, MAAS-03
    "00:E0:81:DD:D5:99": "10.245.143.103",
    # lenovo-RD230-04, MAAS-04
    #"00:E0:81:DD:D1:0B": "10.245.143.104", # TODO: Investigate. Seems broken
    # lenovo-RD230-06, MAAS-06
    "00:E0:81:D1:B1:47": "10.245.143.106",
    # lenovo-RD230-07, MAAS-07
    "00:E0:81:DD:D1:1B": "10.245.143.107",
    # lenovo-RD230-08, MAAS-08
    "00:E0:81:DD:D1:2B": "10.245.143.108",
    # lenovo-RD230-10, MAAS-10
    "00:E0:81:DC:38:6D": "10.245.143.110",
}

BMC_START_IP = '10.245.143.100'
BMC_END_IP = '10.245.143.200'

CLUSTER_CONTROLLER_NODES = None

LENOVO_LAB = REGION_CONTROLLER_NODES
if USE_CC_NODES:
    LENOVO_LAB.update(CLUSTER_CONTROLLER_NODES)

# TODO: mapping is outdated.
ARM_LAB = {
    'fc:2f:40:d8:fb:1a': '192.168.21.50',
    'fc:2f:40:fa:2f:9a': '192.168.21.51',
    'fc:2f:40:ec:73:42': '192.168.21.52',
    'fc:2f:40:d5:87:ce': '192.168.21.53'
}

# PPC64LE
PPC_SYSTEMS = {
    '98:BE:94:02:6A:C8': '10.245.143.113',
}

# ARM64
GIGABYTE_USER = "admin"
GIGABYTE_PASS = "password"
GIGABYTE_SYSTEMS = {
    '1c:1b:0d:0d:52:7c': '10.245.143.114',
}

# HP Gen9
GEN9_USER = 'Administrator'
GEN9_PASS = 'insecure'
GEN9_SYSTEMS = {
    "94:18:82:7a:72:44": "10.245.143.116",
    "94:18:82:7a:72:64": "10.245.143.117", # Investigate
    "94:18:82:7a:82:c8": "10.245.143.118",
    "94:18:82:7a:72:80": "10.245.143.119",
}

# Landscape hardware
LANDSCAPE_USER = 'landscape'
LANDSCAPE_PASS = 'insecure'
LANDSCAPE_SYSTEMS = {
    "2c:59:e5:4a:be:cc": "10.245.143.122", # amco
    "2c:59:e5:3b:c0:e4": "10.245.143.123", # barley
    "ec:b1:d7:80:00:08": "10.245.143.124", # lapras
    "ec:b1:d7:7f:ef:94": "10.245.143.125", # pidgey
    "2c:59:e5:3b:11:28": "10.245.143.126", # squier
    "ec:b1:d7:7f:ef:34": "10.245.143.127", # stunky
}

# Dell Hardware for CentOS / Windows CI testing
USE_DELL_R630_SYSTEMS = bool(os.environ.get('USE_DELL_R630_SYSTEMS', False))
DELL_R630_USER = "root"
DELL_R630_PASS = "calvin"
DELL_R630_SYSTEMS = {
    "f4:8e:38:d0:0e:d2": "10.245.143.120", # natasha
    "f4:8e:38:d0:0b:54": "10.245.143.121", # opelt
}

TEST_CUSTOM_IMAGES = bool(int(os.environ.get('TEST_CUSTOM_IMAGES', False)))
CUSTOM_IMAGES_SOURCE = os.environ.get(
                           'CUSTOM_IMAGES_SOURCE',
                           'http://10.245.136.7/images/streams/v1/index.json')

TEST_WINDOWS = bool(os.environ.get('TEST_WINDOWS', False))
WINDOWS_IMAGE = "/home/ubuntu/windows-win2012hvr2-amd64-root-dd"
TEST_RHEL = bool(os.environ.get('TEST_RHEL', False))
RHEL_IMAGE = "/home/ubuntu/rhel7-amd64-root-tgz"

TEST_PERFORMANCE = bool(os.environ.get('TEST_PERFORMANCE', False))
# dnssec is now enabled by default, so disable it to avoid errors from the
# forwarder server.
# See StackOverflow question "ns got insecure response, parent indicates
# it should be secure": http://bit.ly/1pe8Hkk
UPSTREAM_DNS = "10.245.136.1"
DNSSEC_VALIDATION = "no"
# This is old configuration that's not tested on newer version of MAAS
# that support setting forwarder and changing DNSSec validation.
LAB_DNS_CONFIG = """
options {
    directory "/var/cache/bind";
    forwarders {
    10.245.136.1;
    };
    allow-query-cache {any;};
    dnssec-enable no;
    dnssec-validation no;
    auth-nxdomain no;    # conform to RFC1035
};
"""

JUJU_CONFIG = """
default: maas
environments:
  maas:
    type: maas
    maas-server: '%s'
    maas-oauth: '%s'
    bootstrap-timeout: 18000
    admin-secret: 'nothing'
    default-series: %s
    logging-config: <root>=TRACE
    disable-network-management: true
"""

TEST_JUJU = bool(os.environ.get('TEST_JUJU', False))
